// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_component_copy_with_extension/component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/portfolio_card/widgets/portfolio_card_header.dart';
import 'package:wyatt_ui_kit/src/components/cards/portfolio_card/widgets/portfolio_card_images.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_text.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_wrapper.dart';

part 'portfolio_card.g.dart';

@ComponentCopyWithExtension()
class PortfolioCard extends PortfolioCardComponent with $PortfolioCardCWMixin {
  const PortfolioCard({
    super.showImagesOnTop,
    super.keyword,
    super.description,
    super.logo,
    super.projectName,
    super.subtitle,
    super.ctas,
    super.assets,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.secondaryBackgroundColors,
    super.minSize,
    super.maxSize = const Size(330, double.infinity),
    super.shadow,
    super.background,
    super.key,
  });

  @override
  Widget build(BuildContext context) => CardWrapper(
        background: background,
        padding: padding,
        backgroundColors: backgroundColors,
        borderColors: borderColors,
        shadow: shadow,
        maxSize: maxSize,
        minSize: minSize,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            if (showImagesOnTop ?? false) ...[
              if (assets != null) ...[
                PortfolioCardImages(
                  radius: radius,
                  maxSize: maxSize,
                  images: assets,
                ),
                const Gap(20),
              ],
              CardText(
                description!,
                textType: TextType.body,
                style: description!.style,
                gradientColors: description!.gradientColors,
              ),
              const Gap(20),
              PortfolioCardHeader(
                secondaryBackgroundColors: secondaryBackgroundColors,
                logo: logo,
                padding: padding,
                radius: radius,
                projectName: projectName,
                subtitle: subtitle,
                keyword: keyword,
              ),
            ] else ...[
              PortfolioCardHeader(
                secondaryBackgroundColors: secondaryBackgroundColors,
                logo: logo,
                padding: padding,
                radius: radius,
                projectName: projectName,
                subtitle: subtitle,
                keyword: keyword,
              ),
              const Gap(10),
              if (assets != null) ...[
                PortfolioCardImages(
                  radius: radius,
                  maxSize: maxSize,
                  images: assets,
                ),
                const Gap(20),
              ],
              CardText(
                description!,
                textType: TextType.body,
                style: description!.style,
                gradientColors: description!.gradientColors,
              ),
            ],
            if (ctas != null) ...[const Gap(20), ...ctas!],
          ],
        ),
      );
}
